summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/ui/kopetelistviewitem.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/ui/kopetelistviewitem.cpp')
-rw-r--r--kopete/libkopete/ui/kopetelistviewitem.cpp88
1 files changed, 44 insertions, 44 deletions
diff --git a/kopete/libkopete/ui/kopetelistviewitem.cpp b/kopete/libkopete/ui/kopetelistviewitem.cpp
index 6156b6aa..b66dc1af 100644
--- a/kopete/libkopete/ui/kopetelistviewitem.cpp
+++ b/kopete/libkopete/ui/kopetelistviewitem.cpp
@@ -236,7 +236,7 @@ bool Component::setMinHeight( int height )
return true;
}
-void Component::tqlayout( const TQRect &newRect )
+void Component::layout( const TQRect &newRect )
{
if ( rect().isNull() )
d->startRect = TQRect( newRect.topLeft(), newRect.topLeft() );
@@ -262,26 +262,26 @@ void Component::paint( TQPainter *painter, const TQColorGroup &cg )
}
}
-void Component::tqrepaint()
+void Component::repaint()
{
- d->parent->tqrepaint();
+ d->parent->repaint();
}
-void Component::retqlayout()
+void Component::relayout()
{
- d->parent->retqlayout();
+ d->parent->relayout();
}
void Component::componentAdded( Component *component )
{
ComponentBase::componentAdded( component );
- //update( Retqlayout );
+ //update( Relayout );
}
void Component::componentRemoved( Component *component )
{
ComponentBase::componentRemoved( component );
- //update( Retqlayout );
+ //update( Relayout );
}
// BoxComponent --------
@@ -374,14 +374,14 @@ void BoxComponent::calcMinSize()
}
if ( sizeChanged )
- tqrepaint();
+ repaint();
else
- retqlayout();
+ relayout();
}
-void BoxComponent::tqlayout( const TQRect &rect )
+void BoxComponent::layout( const TQRect &rect )
{
- Component::tqlayout( rect );
+ Component::layout( rect );
bool horiz = (d->direction ==Qt::Horizontal);
int fixedSize = 0;
@@ -437,7 +437,7 @@ void BoxComponent::tqlayout( const TQRect &rect )
pos += rc.height();
remaining -= rc.height() - minHeight;
}
- comp->tqlayout( rc & rect );
+ comp->layout( rc & rect );
pos += padding;
}
}
@@ -518,7 +518,7 @@ void ContactBoxComponent::reloadTheme()
d->bottom_pixmap.load(str);
}
-void ContactBoxComponent::tqlayout(const TQRect &rect)
+void ContactBoxComponent::layout(const TQRect &rect)
{
d->sub.setLeft(rect.left() +
d->left_pixmap.width());
@@ -529,8 +529,8 @@ void ContactBoxComponent::tqlayout(const TQRect &rect)
d->sub.setBottom(rect.bottom() -
d->bottom_pixmap.height());
- BoxComponent::tqlayout(d->sub);
- Component::tqlayout(rect);
+ BoxComponent::layout(d->sub);
+ Component::layout(rect);
}
int ContactBoxComponent::widthForHeight(int height)
@@ -661,7 +661,7 @@ void GroupBoxComponent::reloadTheme()
d->bottom_pixmap.load(str);
}
-void GroupBoxComponent::tqlayout(const TQRect &rect)
+void GroupBoxComponent::layout(const TQRect &rect)
{
d->sub.setLeft(rect.left() +
d->left_pixmap.width());
@@ -672,8 +672,8 @@ void GroupBoxComponent::tqlayout(const TQRect &rect)
d->sub.setBottom(rect.bottom() -
d->bottom_pixmap.height());
- BoxComponent::tqlayout(d->sub);
- Component::tqlayout(rect);
+ BoxComponent::layout(d->sub);
+ Component::layout(rect);
}
int GroupBoxComponent::widthForHeight(int height)
@@ -758,7 +758,7 @@ ImageComponent::ImageComponent( ComponentBase *parent, int minW, int minH )
{
setMinWidth( minW );
setMinHeight( minH );
- tqrepaint();
+ repaint();
}
ImageComponent::~ImageComponent()
@@ -777,7 +777,7 @@ void ImageComponent::setPixmap( const TQPixmap &img, bool)
setMinWidth(d->image.width());
setMinHeight(d->image.height());
- tqrepaint();
+ repaint();
}
void ImageComponent::paint( TQPainter *painter, const TQColorGroup & )
@@ -814,7 +814,7 @@ void FaceComponent::setPixmap(const TQPixmap &img, bool)
setMinHeight(d->image.height() + 4);
}
- tqrepaint();
+ repaint();
}
static TQPoint operator+(const TQPoint &pt, const TQSize &sz)
@@ -881,7 +881,7 @@ void TextComponent::setText( const TQString &text )
{
if ( text == d->text ) return;
d->text = text;
- retqlayout();
+ relayout();
calcMinSize();
}
@@ -906,7 +906,7 @@ void TextComponent::calcMinSize()
else
setMinHeight( 0 );
- tqrepaint();
+ repaint();
}
int TextComponent::widthForHeight( int )
@@ -927,13 +927,13 @@ void TextComponent::setColor( const TQColor &color )
{
d->color = color;
d->customColor = true;
- tqrepaint();
+ repaint();
}
void TextComponent::setDefaultColor()
{
d->customColor = false;
- tqrepaint();
+ repaint();
}
void TextComponent::paint( TQPainter *painter, const TQColorGroup &cg )
@@ -968,9 +968,9 @@ DisplayNameComponent::~DisplayNameComponent()
delete d;
}
-void DisplayNameComponent::tqlayout( const TQRect &rect )
+void DisplayNameComponent::layout( const TQRect &rect )
{
- Component::tqlayout( rect );
+ Component::layout( rect );
// finally, lay everything out
TQRect rc;
@@ -989,7 +989,7 @@ void DisplayNameComponent::tqlayout( const TQRect &rect )
if ( comp->rtti() == Rtti_TextComponent )
{
comp->show();
- comp->tqlayout( TQRect( usedWidth+ rect.left(), rect.top(),
+ comp->layout( TQRect( usedWidth+ rect.left(), rect.top(),
totalWidth - usedWidth,
comp->heightForWidth( totalWidth - usedWidth ) ) );
} else {
@@ -999,7 +999,7 @@ void DisplayNameComponent::tqlayout( const TQRect &rect )
else
{
comp->show();
- comp->tqlayout( TQRect( usedWidth+ rect.left(), rect.top(),
+ comp->layout( TQRect( usedWidth+ rect.left(), rect.top(),
comp->widthForHeight( rect.height() ),
comp->heightForWidth( rect.width() ) ) );
}
@@ -1145,7 +1145,7 @@ ContactComponent::~ContactComponent()
void ContactComponent::updatePixmap()
{
- setPixmap( contact()->onlinetqStatus().iconFor( contact(), d->iconSize ) );
+ setPixmap( contact()->onlineStatus().iconFor( contact(), d->iconSize ) );
}
Kopete::Contact *ContactComponent::contact()
{
@@ -1316,13 +1316,13 @@ void Item::initLVI()
void Item::slotColumnResized()
{
scheduleLayout();
- // if we've been resized, don't animate the tqlayout
+ // if we've been resized, don't animate the layout
d->animateLayout = false;
}
void Item::scheduleLayout()
{
// perform a delayed tqlayout in order to speed it all up
if ( ! d->layoutTimer.isActive() )
d->layoutTimer.start( 30, true );
}
@@ -1341,7 +1341,7 @@ void Item::slotLayoutItems()
}
int height = component( n )->heightForWidth( width );
- component( n )->tqlayout( TQRect( 0, 0, width, height ) );
+ component( n )->layout( TQRect( 0, 0, width, height ) );
//kdDebug(14000) << k_funcinfo << "Component " << n << " is " << width << " x " << height << endl;
}
@@ -1370,7 +1370,7 @@ void Item::slotLayoutAnimateItems()
updateAnimationPosition( p, s );
setHeight(0);
- tqrepaint();
+ repaint();
}
float Item::opacity()
@@ -1382,7 +1382,7 @@ void Item::setOpacity( float opacity )
{
if ( d->opacity == opacity ) return;
d->opacity = opacity;
- tqrepaint();
+ repaint();
}
void Item::setSearchMatch( bool match )
@@ -1451,18 +1451,18 @@ void Item::slotUpdateVisibility()
setVisible( false );
}
setHeight( 0 );
- tqrepaint();
+ repaint();
}
-void Item::tqrepaint()
+void Item::repaint()
{
- // if we're about to retqlayout, don't bother painting yet.
+ // if we're about to relayout, don't bother painting yet.
if ( d->layoutTimer.isActive() )
return;
listView()->repaintItem( this );
}
-void Item::retqlayout()
+void Item::relayout()
{
scheduleLayout();
}
@@ -1489,7 +1489,7 @@ void Item::setHeight( int )
int Item::width( const TQFontMetrics &, const TQListView *lv, int c ) const
{
- // TQt computes the tqitemRect from this. we want the whole item to be
+ // TQt computes the itemRect from this. we want the whole item to be
// clickable, so we return the widest we could possibly be.
return lv->header()->sectionSize( c );
}
@@ -1528,7 +1528,7 @@ void Item::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int widt
const BackgroundMode bgmode = lv->viewport()->backgroundMode();
const TQColorGroup::ColorRole crole = TQPalette::backgroundRoleFromMode( bgmode );
- if ( _cg.brush( crole ) != lv->tqcolorGroup().brush( crole ) )
+ if ( _cg.brush( crole ) != lv->colorGroup().brush( crole ) )
p->fillRect( 0, 0, width, height(), _cg.brush( crole ) );
else
{
@@ -1540,8 +1540,8 @@ void Item::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int widt
if ( lv->isEnabled() )
how |= TQStyle::Style_Enabled;
- lv->tqstyle().tqdrawComplexControl( TQStyle::CC_ListView,
- p, lv, TQRect( 0, 0, width, height() ), lv->tqcolorGroup(),
+ lv->tqstyle().drawComplexControl( TQStyle::CC_ListView,
+ p, lv, TQRect( 0, 0, width, height() ), lv->colorGroup(),
how, TQStyle::SC_ListView, TQStyle::SC_None,
opt );
}
@@ -1565,7 +1565,7 @@ void Item::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int widt
textheight++;
if ( textheight < height() ) {
int w = lv->treeStepSize() / 2;
- lv->tqstyle().tqdrawComplexControl( TQStyle::CC_ListView, p, lv,
+ lv->tqstyle().drawComplexControl( TQStyle::CC_ListView, p, lv,
TQRect( 0, textheight, w + 1, height() - textheight + 1 ), _cg,
lv->isEnabled() ? TQStyle::Style_Enabled : TQStyle::Style_Default,
TQStyle::SC_ListViewExpand,
@@ -1316,13 +1316,13 @@ void Item::initLVI()
void Item::scheduleLayout()
{
- // perform a delayed tqlayout in order to speed it all up
+ // perform a delayed layout in order to speed it all up
if ( ! d->layoutTimer.isActive() )
d->layoutTimer.start( 30, true );